##  Add Key Milestones and Set the Lifecycle
As your initiatives grow and dependencies between applications emerge, use shared milestones to coordinate efforts across teams. Reference these in the **Lifecycle** section of your initiatives to set up tracking based on your unique goals.
For details on how milestones can help you synchronize transformation steps and visualize impact across your landscape, visit [Milestones](https://help.sap.com/docs/leanix/ea/milestones?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to add and manage milestones and realize their value by effectively visualizing them in reports.").
To add a milestone and set the lifecycle, do the following:
  1. In the initiative, hover over the Milestones section and choose Add.
  2. Enter a name, target date, and description.
The Description field is optional, but it is a good practice to fill it out because it offers additional context to other stakeholders involved in the project.
  3. Choose Save.
  4. Go to the Lifecycle section and choose Edit.
  5. To switch from absolute date to milestones, choose the diamond-shaped milestone icon next to each lifecycle field.
  6. Select the required milestone from the dropdown.
  7. Choose Save.


Initiative with Milestone-Based Lifecycle
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiof0709c915e1e4a489af97070157321c0_LowRes.png)
